==> igniteui-angular-charts-17.3.0.tgz: package/esm5/lib/TypicalPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TypicalPriceIndicatorStrategy } from "./TypicalPriceIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var TypicalPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TypicalPriceIndicator, _super);
    function TypicalPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TypicalPriceIndicator.prototype.bc = function () {
        return new TypicalPriceIndicator();
    };
    TypicalPriceIndicator.prototype.get_y0 = function () {
        return new TypicalPriceIndicatorStrategy();
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "y0", {
        get: function () {
            return this.get_y0();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.prototype.get_zd = function () {
        return TypicalPriceIndicator.$;
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "zd", {
        get: function () {
            return this.get_zd();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.$t = markType(TypicalPriceIndicator, 'TypicalPriceIndicator', StrategyBasedIndicator.$);
    return TypicalPriceIndicator;
}(StrategyBasedIndicator));
export { TypicalPriceIndicator };

==> igniteui-angular-charts-18.0.0.tgz: package/esm5/lib/TypicalPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TypicalPriceIndicatorStrategy } from "./TypicalPriceIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var TypicalPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TypicalPriceIndicator, _super);
    function TypicalPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TypicalPriceIndicator.prototype.bb = function () {
        return new TypicalPriceIndicator();
    };
    TypicalPriceIndicator.prototype.get_aaa = function () {
        return new TypicalPriceIndicatorStrategy();
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "aaa", {
        get: function () {
            return this.get_aaa();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.prototype.get_aan = function () {
        return TypicalPriceIndicator.$;
    };
    Object.defineProperty(TypicalPriceIndicator.prototype, "aan", {
        get: function () {
            return this.get_aan();
        },
        enumerable: false,
        configurable: true
    });
    TypicalPriceIndicator.$t = markType(TypicalPriceIndicator, 'TypicalPriceIndicator', StrategyBasedIndicator.$);
    return TypicalPriceIndicator;
}(StrategyBasedIndicator));
export { TypicalPriceIndicator };
